@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2021 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -41,10 +41,8 @@ import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 import javax.inject.Named;
-import org.eclipse.che.api.core.NotFoundException;
 import org.eclipse.che.api.core.ServerException;
 import org.eclipse.che.api.core.ValidationException;
-import org.eclipse.che.api.core.model.user.User;
 import org.eclipse.che.api.core.model.workspace.Workspace;
 import org.eclipse.che.api.core.model.workspace.runtime.RuntimeIdentity;
 import org.eclipse.che.api.user.server.PreferenceManager;
@@ -267,42 +265,11 @@ public class KubernetesNamespaceFactory {
    * Tells the caller whether the namespace that is being prepared for the provided workspace
    * runtime identity can be created or is expected to already be present.
    *
-   * <p>Note that this method cannot be reduced to merely checking if user-defined namespaces are
-   * allowed or not (and depending on prior validation using the {@link
-   * #checkIfNamespaceIsAllowed(String)} method during the workspace creation) because workspace
-   * start is a) async from workspace creation and the underlying namespaces might have disappeared
-   * and b) can be called during workspace recovery, where we don't even have the current user in
-   * the context.
-   *
-   * @param identity the identity of the workspace runtime
    * @return true if the namespace can be created, false if the namespace is expected to already
    *     exist
-   * @throws InfrastructureException on failure
    */
-  protected boolean canCreateNamespace(RuntimeIdentity identity) throws InfrastructureException {
-    if (!namespaceCreationAllowed) {
-      return false;
-    }
-
-    // we need to make sure that the provided namespace is indeed the one provided by our
-    // configuration
-    User owner;
-    try {
-      owner = userManager.getById(identity.getOwnerId());
-    } catch (NotFoundException | ServerException e) {
-      throw new InfrastructureException(
-          "Failed to resolve workspace owner. Cause: " + e.getMessage(), e);
-    }
-
-    String requiredNamespace = identity.getInfrastructureNamespace();
-
-    NamespaceResolutionContext resolutionContext =
-        new NamespaceResolutionContext(
-            identity.getWorkspaceId(), identity.getOwnerId(), owner.getName());
-
-    String resolvedDefaultNamespace = evaluateNamespaceName(resolutionContext);
-
-    return resolvedDefaultNamespace.equals(requiredNamespace);
+  protected boolean canCreateNamespace() {
+    return namespaceCreationAllowed;
   }
 
   /**
@@ -320,14 +287,14 @@ public class KubernetesNamespaceFactory {
     KubernetesNamespace namespace = get(identity);
 
     var subject = EnvironmentContext.getCurrent().getSubject();
+    var userName = subject.getUserName();
     NamespaceResolutionContext resolutionCtx =
-        new NamespaceResolutionContext(
-            identity.getWorkspaceId(), subject.getUserId(), subject.getUserName());
+        new NamespaceResolutionContext(identity.getWorkspaceId(), subject.getUserId(), userName);
     Map<String, String> namespaceAnnotationsEvaluated =
         evaluateAnnotationPlaceholders(resolutionCtx);
 
     namespace.prepare(
-        canCreateNamespace(identity),
+        canCreateNamespace(),
         labelNamespaces ? namespaceLabels : emptyMap(),
         annotateNamespaces ? namespaceAnnotationsEvaluated : emptyMap());
 
@@ -515,9 +482,6 @@ public class KubernetesNamespaceFactory {
         "Evaluated the namespace for workspace {} using the namespace default to {}",
         resolutionCtx.getWorkspaceId(),
         namespace);
-
-    recordEvaluatedNamespaceName(namespace, resolutionCtx);
-
     return namespace;
   }
 
