@@ -22,7 +22,7 @@ import javax.inject.Inject;
 import javax.inject.Singleton;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.BadRequestException;
-import org.eclipse.che.api.factory.server.DefaultFactoryParameterResolver;
+import org.eclipse.che.api.factory.server.RawDevfileUrlFactoryParameterResolver;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
 import org.eclipse.che.api.factory.server.urlfactory.URLFactoryBuilder;
@@ -41,7 +41,7 @@ import org.eclipse.che.api.workspace.shared.dto.devfile.SourceDto;
  * @author Max Shaposhnyk
  */
 @Singleton
-public class GitlabFactoryParametersResolver extends DefaultFactoryParameterResolver {
+public class GitlabFactoryParametersResolver extends RawDevfileUrlFactoryParameterResolver {
 
   private final GitlabUrlParser gitlabURLParser;
   private final PersonalAccessTokenManager personalAccessTokenManager;
